@@ -56,9 +56,8 @@ ViewText::ViewText ()
 ////////////////////////////////////////////////////////////////////////////////
 ViewText::~ViewText ()
 {
-  std::vector <Column*>::iterator i;
-  for (i = _columns.begin (); i != _columns.end (); ++i)
-    delete *i;
+  for (auto& col : _columns)
+    delete col;
 
   _columns.clear ();
 }
@@ -92,17 +91,6 @@ void ViewText::set (int row, int col, int value, Color color)
     _color[row][col] = color;
 }
 
-////////////////////////////////////////////////////////////////////////////////
-void ViewText::set (int row, int col, float value, int width, int precision, Color color)
-{
-  std::string string_value = format ((float)value, width, precision);
-  _data[row][col] = string_value;
-
-  if (color.nontrivial () &&
-      context.color ())
-    _color[row][col] = color;
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 void ViewText::set (int row, int col, Color color)
 {
@@ -114,6 +102,8 @@ void ViewText::set (int row, int col, Color color)
 ////////////////////////////////////////////////////////////////////////////////
 std::string ViewText::render ()
 {
+  bool const obfuscate = context.config.getBoolean ("obfuscate");
+
   // Determine minimal, ideal column widths.
   std::vector <int> minimal;
   std::vector <int> ideal;
@@ -145,14 +135,13 @@ std::string ViewText::render ()
 
   // Sum the minimal widths.
   int sum_minimal = 0;
-  std::vector <int>::iterator c;
-  for (c = minimal.begin (); c != minimal.end (); ++c)
-    sum_minimal += *c;
+  for (auto& c : minimal)
+    sum_minimal += c;
 
   // Sum the ideal widths.
   int sum_ideal = 0;
-  for (c = ideal.begin (); c != ideal.end (); ++c)
-    sum_ideal += *c;
+  for (auto& c : ideal)
+    sum_ideal += c;
 
   // Calculate final column widths.
   int overage = _width
@@ -265,6 +254,11 @@ std::string ViewText::render ()
 
       if (cells[col].size () > max_lines)
         max_lines = cells[col].size ();
+
+      if (obfuscate)
+        if (_columns[col]->type () == "string")
+          for (unsigned int line = 0; line < cells[col].size (); ++line)
+            cells[col][line] = obfuscateText (cells[col][line]);
     }
 
     for (unsigned int i = 0; i < max_lines; ++i)
