@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2014, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -43,11 +42,17 @@ extern Context context;
 ////////////////////////////////////////////////////////////////////////////////
 CmdCalendar::CmdCalendar ()
 {
-  _keyword     = "calendar";
-  _usage       = "task          calendar [due|<month> <year>|<year>] [y]";
-  _description = STRING_CMD_CAL_USAGE;
-  _read_only   = true;
-  _displays_id = true;
+  _keyword               = "calendar";
+  _usage                 = "task          calendar [due|<month> <year>|<year>] [y]";
+  _description           = STRING_CMD_CAL_USAGE;
+  _read_only             = true;
+  _displays_id           = true;
+  _needs_gc              = true;
+  _uses_context          = true;
+  _accepts_filter        = false;
+  _accepts_modifications = false;
+  _accepts_miscellaneous = true;
+  _category              = Command::Category::graphs;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -67,10 +72,9 @@ int CmdCalendar::execute (std::string& output)
 
   // Load the pending tasks.
   handleRecurrence ();
-  context.tdb2.commit ();
-  std::vector <Task> tasks = context.tdb2.pending.get_tasks ();
+  auto tasks = context.tdb2.pending.get_tasks ();
 
-  Date today;
+  ISO8601d today;
   bool getpendingdate = false;
   int monthsToDisplay = 1;
   int mFrom = today.month ();
@@ -94,7 +98,7 @@ int CmdCalendar::execute (std::string& output)
   // Set up a vector of months, for autoComplete.
   std::vector <std::string> monthNames;
   for (int i = 1; i <= 12; ++i)
-    monthNames.push_back (lowerCase (Date::monthName (i)));
+    monthNames.push_back (lowerCase (ISO8601d::monthName (i)));
 
   // For autoComplete results.
   std::vector <std::string> matches;
@@ -104,45 +108,44 @@ int CmdCalendar::execute (std::string& output)
   int argYear = 0;
   bool argWholeYear = false;
 
-  std::vector <std::string> words = context.a3.extract_words ();
+  std::vector <std::string> words = context.cli2.getWords ();
 
-  std::vector <std::string>::iterator arg;
-  for (arg = words.begin (); arg != words.end (); ++arg)
+  for (auto& arg : words)
   {
     // Some version of "calendar".
-    if (autoComplete (lowerCase (*arg), commandNames, matches, context.config.getInteger ("abbreviation.minimum")) == 1)
+    if (autoComplete (lowerCase (arg), commandNames, matches, context.config.getInteger ("abbreviation.minimum")) == 1)
       continue;
 
     // "due".
-    else if (autoComplete (lowerCase (*arg), keywordNames, matches, context.config.getInteger ("abbreviation.minimum")) == 1)
+    else if (autoComplete (lowerCase (arg), keywordNames, matches, context.config.getInteger ("abbreviation.minimum")) == 1)
       getpendingdate = true;
 
     // "y".
-    else if (lowerCase (*arg) == "y")
+    else if (lowerCase (arg) == "y")
       argWholeYear = true;
 
     // YYYY.
-    else if (digitsOnly (*arg) && arg->length () == 4)
-      argYear = strtol (arg->c_str (), NULL, 10);
+    else if (Lexer::isAllDigits (arg) && arg.length () == 4)
+      argYear = strtol (arg.c_str (), NULL, 10);
 
     // MM.
-    else if (digitsOnly (*arg) && arg->length () <= 2)
+    else if (Lexer::isAllDigits (arg) && arg.length () <= 2)
     {
-      argMonth = strtol (arg->c_str (), NULL, 10);
+      argMonth = strtol (arg.c_str (), NULL, 10);
       if (argMonth < 1 || argMonth > 12)
-        throw format (STRING_CMD_CAL_BAD_MONTH, *arg);
+        throw format (STRING_CMD_CAL_BAD_MONTH, arg);
     }
 
     // "January" etc.
-    else if (autoComplete (lowerCase (*arg), monthNames, matches, context.config.getInteger ("abbreviation.minimum")) == 1)
+    else if (autoComplete (lowerCase (arg), monthNames, matches, context.config.getInteger ("abbreviation.minimum")) == 1)
     {
-      argMonth = Date::monthOfYear (matches[0]);
+      argMonth = ISO8601d::monthOfYear (matches[0]);
       if (argMonth == -1)
-        throw format (STRING_CMD_CAL_BAD_MONTH, *arg);
+        throw format (STRING_CMD_CAL_BAD_MONTH, arg);
     }
 
     else
-      throw format (STRING_CMD_CAL_BAD_ARG, *arg);
+      throw format (STRING_CMD_CAL_BAD_ARG, arg);
   }
 
   // Supported combinations:
@@ -173,17 +176,16 @@ int CmdCalendar::execute (std::string& output)
   if (getpendingdate == true)
   {
     // Find the oldest pending due date.
-    Date oldest (12, 31, 2037);
-    std::vector <Task>::iterator task;
-    for (task = tasks.begin (); task != tasks.end (); ++task)
+    ISO8601d oldest (12, 31, 2037);
+    for (auto& task : tasks)
     {
-      if (task->getStatus () == Task::pending)
+      if (task.getStatus () == Task::pending)
       {
-        if (task->has ("due") &&
-            !task->hasTag ("nocal"))
+        if (task.has ("due") &&
+            !task.hasTag ("nocal"))
         {
           ++countDueDates;
-          Date d (task->get ("due"));
+          ISO8601d d (task.get ("due"));
           if (d < oldest) oldest = d;
         }
       }
@@ -232,7 +234,7 @@ int CmdCalendar::execute (std::string& output)
     // Print month headers (cheating on the width settings, yes)
     for (int i = 0 ; i < monthsPerLine ; i++)
     {
-      std::string month = Date::monthName (nextM);
+      std::string month = ISO8601d::monthName (nextM);
 
       //    12345678901234567890123456 = 26 chars wide
       //                ^^             = center
@@ -286,6 +288,7 @@ int CmdCalendar::execute (std::string& output)
   Color color_weekend    (context.config.get ("color.calendar.weekend"));
   Color color_holiday    (context.config.get ("color.calendar.holiday"));
   Color color_weeknumber (context.config.get ("color.calendar.weeknumber"));
+  Color color_label      (context.config.get ("color.label"));
 
   if (context.color () && context.config.getBoolean ("calendar.legend"))
     out << "Legend: "
@@ -314,7 +317,7 @@ int CmdCalendar::execute (std::string& output)
       details_mFrom = 12;
       --details_yFrom;
     }
-    int details_dFrom = Date::daysInMonth (details_mFrom, details_yFrom);
+    int details_dFrom = ISO8601d::daysInMonth (details_mFrom, details_yFrom);
 
     ++mTo;
     if (mTo == 13)
@@ -323,29 +326,40 @@ int CmdCalendar::execute (std::string& output)
       ++yTo;
     }
 
-    Date date_after (details_mFrom, details_dFrom, details_yFrom);
+    ISO8601d date_after (details_mFrom, details_dFrom, details_yFrom);
     std::string after = date_after.toString (context.config.get ("dateformat"));
 
-    Date date_before (mTo, 1, yTo);
+    ISO8601d date_before (mTo, 1, yTo);
     std::string before = date_before.toString (context.config.get ("dateformat"));
 
     // Table with due date information
     if (context.config.get ("calendar.details") == "full")
     {
+      // Assert that 'report' is a valid report.
       std::string report = context.config.get ("calendar.details.report");
-      std::string report_filter = context.config.get ("report." + report + ".filter");
+      if (context.commands.find (report) == context.commands.end ())
+        throw std::string (STRING_ERROR_DETAILS);
 
-      context.a3.clear ();
-      context.a3.push_back (Arg ("task", Arg::cat_program));
+      // TODO Fix this:  cal      --> task
+      //                 calendar --> taskendar
 
-      report_filter += " due.after:" + after + " due.before:" + before + " -nocal";
-      context.config.set ("report." + report + ".filter", report_filter);
+      // If the executable was "cal" or equivalent, replace it with "task".
+      std::string executable = context.cli2._original_args[0].attribute ("raw");
+      auto cal = executable.find ("cal");
+      if (cal != std::string::npos)
+        executable = executable.substr (0, cal) + PACKAGE;
 
-      // Display all due task in the report colorized not only the imminet ones
-      context.config.set ("due", 0);
+      std::vector <std::string> args;
+      args.push_back ("rc:" + context.rc_file._data);
+      args.push_back ("rc.due:0");
+      args.push_back ("rc.verbose:label,affected,blank");
+      args.push_back ("due.after:" + after);
+      args.push_back ("due.before:" + before);
+      args.push_back ("-nocal");
+      args.push_back (report);
 
       std::string output;
-      context.commands[report]->execute (output);
+      ::execute (executable, args, "", output);
       out << output;
     }
 
@@ -356,21 +370,19 @@ int CmdCalendar::execute (std::string& output)
       holTable.width (context.getWidth ());
       holTable.add (Column::factory ("string", STRING_CMD_CAL_LABEL_DATE));
       holTable.add (Column::factory ("string", STRING_CMD_CAL_LABEL_HOL));
+      holTable.colorHeader (color_label);
 
-      Config::const_iterator it;
-      std::map <time_t, std::vector<std::string> > hm; // we need to store multiple holidays per day
-      for (it = context.config.begin (); it != context.config.end (); ++it)
-        if (it->first.substr (0, 8) == "holiday.")
-          if (it->first.substr (it->first.size () - 4) == "name")
+      std::map <time_t, std::vector<std::string>> hm; // we need to store multiple holidays per day
+      for (auto& it : context.config)
+        if (it.first.substr (0, 8) == "holiday.")
+          if (it.first.substr (it.first.size () - 4) == "name")
           {
-            std::string holName = context.config.get ("holiday." + it->first.substr (8, it->first.size () - 13) + ".name");
-            std::string holDate = context.config.get ("holiday." + it->first.substr (8, it->first.size () - 13) + ".date");
-            Date hDate (holDate.c_str (), context.config.get ("dateformat.holiday"));
+            std::string holName = context.config.get ("holiday." + it.first.substr (8, it.first.size () - 13) + ".name");
+            std::string holDate = context.config.get ("holiday." + it.first.substr (8, it.first.size () - 13) + ".date");
+            ISO8601d hDate (holDate.c_str (), context.config.get ("dateformat.holiday"));
 
             if (date_after < hDate && hDate < date_before)
-            {
               hm[hDate.toEpoch()].push_back(holName);
-            }
           }
 
       std::string format = context.config.get ("report." +
@@ -381,11 +393,10 @@ int CmdCalendar::execute (std::string& output)
       if (format == "")
         format = context.config.get ("dateformat");
 
-      std::map <time_t, std::vector<std::string> >::iterator hm_it;
-      for (hm_it = hm.begin(); hm_it != hm.end(); ++hm_it)
+      for (auto& hm_it : hm)
       {
-        std::vector <std::string> v = hm_it->second;
-        Date hDate (hm_it->first);
+        std::vector <std::string> v = hm_it.second;
+        ISO8601d hDate (hm_it.first);
         std::string d = hDate.toString (format);
         for (size_t i = 0; i < v.size(); i++)
         {
@@ -409,41 +420,44 @@ int CmdCalendar::execute (std::string& output)
 std::string CmdCalendar::renderMonths (
   int firstMonth,
   int firstYear,
-  const Date& today,
+  const ISO8601d& today,
   std::vector <Task>& all,
   int monthsPerLine)
 {
   // What day of the week does the user consider the first?
-  int weekStart = Date::dayOfWeek (context.config.get ("weekstart"));
+  int weekStart = ISO8601d::dayOfWeek (context.config.get ("weekstart"));
   if (weekStart != 0 && weekStart != 1)
     throw std::string (STRING_CMD_CAL_SUN_MON);
 
   // Build table for the number of months to be displayed.
+  Color label (context.config.get ("color.label"));
+
   ViewText view;
+  view.colorHeader (label);
   view.width (context.getWidth ());
   for (int i = 0 ; i < (monthsPerLine * 8); i += 8)
   {
     if (weekStart == 1)
     {
       view.add (Column::factory ("string.right", "    "));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (1), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (2), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (3), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (4), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (5), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (6), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (0), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (1), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (2), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (3), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (4), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (5), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (6), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (0), 0, 2)));
     }
     else
     {
       view.add (Column::factory ("string.right", "    "));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (0), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (1), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (2), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (3), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (4), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (5), 0, 2)));
-      view.add (Column::factory ("string.right", utf8_substr (Date::dayName (6), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (0), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (1), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (2), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (3), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (4), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (5), 0, 2)));
+      view.add (Column::factory ("string.right", utf8_substr (ISO8601d::dayName (6), 0, 2)));
     }
   }
 
@@ -473,7 +487,7 @@ std::string CmdCalendar::renderMonths (
       years.push_back (++thisYear);
     }
     months.push_back (thisMonth);
-    daysInMonth.push_back (Date::daysInMonth (thisMonth++, thisYear));
+    daysInMonth.push_back (ISO8601d::daysInMonth (thisMonth++, thisYear));
   }
 
   int row = 0;
@@ -496,7 +510,7 @@ std::string CmdCalendar::renderMonths (
     // Loop through days in month and add to table.
     for (int d = 1; d <= daysInMonth[mpl]; ++d)
     {
-      Date temp (months[mpl], d, years[mpl]);
+      ISO8601d temp (months[mpl], d, years[mpl]);
       int dow = temp.dayOfWeek ();
       int woy = temp.weekOfYear (weekStart);
 
@@ -524,13 +538,12 @@ std::string CmdCalendar::renderMonths (
         // colorize holidays
         if (context.config.get ("calendar.holidays") != "none")
         {
-          Config::const_iterator hol;
-          for (hol = context.config.begin (); hol != context.config.end (); ++hol)
-            if (hol->first.substr (0, 8) == "holiday.")
-              if (hol->first.substr (hol->first.size () - 4) == "date")
+          for (auto& hol : context.config)
+            if (hol.first.substr (0, 8) == "holiday.")
+              if (hol.first.substr (hol.first.size () - 4) == "date")
               {
-                std::string value = hol->second;
-                Date holDate (value.c_str (), context.config.get ("dateformat.holiday"));
+                std::string value = hol.second;
+                ISO8601d holDate (value.c_str (), context.config.get ("dateformat.holiday"));
                 if (holDate.day   () == d           &&
                     holDate.month () == months[mpl] &&
                     holDate.year  () == years[mpl])
@@ -548,37 +561,37 @@ std::string CmdCalendar::renderMonths (
         if (context.config.get ("calendar.details") != "none")
         {
           context.config.set ("due", 0);
-          std::vector <Task>::iterator task;
-          for (task = all.begin (); task != all.end (); ++task)
+          for (auto& task : all)
           {
-            if (task->getStatus () == Task::pending &&
-                !task->hasTag ("nocal")             &&
-                task->has ("due"))
+            if (task.getStatus () == Task::pending &&
+                !task.hasTag ("nocal")             &&
+                task.has ("due"))
             {
-              std::string due = task->get ("due");
-              Date duedmy (strtol (due.c_str(), NULL, 10));
+              std::string due = task.get ("due");
+              ISO8601d duedmy (strtol (due.c_str(), NULL, 10));
 
               if (duedmy.day   () == d           &&
                   duedmy.month () == months[mpl] &&
                   duedmy.year  () == years[mpl])
               {
-                switch (getDueState (due))
+                switch (task.getDateState ("due"))
                 {
-                  case 1: // imminent
-                    cellColor.blend (color_due);
-                    break;
+                case Task::dateNotDue:
+                  break;
 
-                  case 2: // today
-                    cellColor.blend (color_duetoday);
-                    break;
+                case Task::dateAfterToday:
+                  cellColor.blend (color_due);
+                  break;
 
-                  case 3: // overdue
-                    cellColor.blend (color_overdue);
-                    break;
+                case Task::dateEarlierToday:
+                case Task::dateLaterToday:
+                  cellColor.blend (color_duetoday);
+                  cellColor.blend (color_duetoday);
+                  break;
 
-                  case 0: // not due at all
-                  default:
-                    break;
+                case Task::dateBeforeToday:
+                  cellColor.blend (color_overdue);
+                  break;
                 }
               }
             }
