@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2014, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -29,50 +28,62 @@
 #include <iostream>
 #include <sstream>
 #include <stdlib.h>
+#include <cstring>
 #include <algorithm>
 #include <unistd.h>
-#include <Duration.h>
+#include <ISO8601.h>
 #include <Context.h>
+#include <Filter.h>
+#include <Nibbler.h>
 #include <i18n.h>
 #include <text.h>
 #include <util.h>
 #include <i18n.h>
 #include <main.h>
 #include <CmdEdit.h>
+#include <JSON.h>
 
 extern Context context;
 
 ////////////////////////////////////////////////////////////////////////////////
 CmdEdit::CmdEdit ()
 {
-  _keyword     = "edit";
-  _usage       = "task <filter> edit";
-  _description = STRING_CMD_EDIT_USAGE;
-  _read_only   = false;
-  _displays_id = false;
+  _keyword               = "edit";
+  _usage                 = "task <filter> edit";
+  _description           = STRING_CMD_EDIT_USAGE;
+  _read_only             = false;
+  _displays_id           = false;
+  _needs_gc              = false;
+  _uses_context          = true;
+  _accepts_filter        = true;
+  _accepts_modifications = false;
+  _accepts_miscellaneous = false;
+  _category              = Command::Category::operation;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 // Introducing the Silver Bullet.  This feature is the catch-all fixative for
 // various other ills.  This is like opening up the hood and going in with a
 // wrench.  To be used sparingly.
-int CmdEdit::execute (std::string& output)
+int CmdEdit::execute (std::string&)
 {
-  int rc = 0;
-
   // Filter the tasks.
   handleRecurrence ();
+  Filter filter;
   std::vector <Task> filtered;
-  filter (filtered);
+  filter.subset (filtered);
 
-  // Find number of matching tasks.  Skip recurring parent tasks.
-  std::vector <Task>::iterator task;
-  for (task = filtered.begin (); task != filtered.end (); ++task)
-    if (editFile (*task))
-      context.tdb2.modify (*task);
+  // Find number of matching tasks.
+  for (auto& task : filtered)
+  {
+    CmdEdit::editResult result = editFile (task);
+    if (result == CmdEdit::editResult::error)
+      break;
+    else if (result == CmdEdit::editResult::changes)
+      context.tdb2.modify (task);
+  }
 
-  context.tdb2.commit ();
-  return rc;
+  return 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -80,10 +91,10 @@ std::string CmdEdit::findValue (
   const std::string& text,
   const std::string& name)
 {
-  std::string::size_type found = text.find (name);
+  auto found = text.find (name);
   if (found != std::string::npos)
   {
-    std::string::size_type eol = text.find ("\n", found + 1);
+    auto eol = text.find ("\n", found + 1);
     if (eol != std::string::npos)
     {
       std::string value = text.substr (
@@ -97,6 +108,26 @@ std::string CmdEdit::findValue (
   return "";
 }
 
+////////////////////////////////////////////////////////////////////////////////
+std::string CmdEdit::findMultilineValue (
+  const std::string& text,
+  const std::string& startMarker,
+  const std::string& endMarker)
+{
+  auto start = text.find (startMarker);
+  if (start != std::string::npos)
+  {
+    auto end = text.find (endMarker, start);
+    if (end != std::string::npos)
+    {
+      std::string value = text.substr (start + startMarker.length (),
+                                       end - (start + startMarker.length ()));
+      return trim (value, "\t ");
+    }
+  }
+  return "";
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 std::vector <std::string> CmdEdit::findValues (
   const std::string& text,
@@ -110,7 +141,7 @@ std::vector <std::string> CmdEdit::findValues (
     found = text.find (name, found + 1);
     if (found != std::string::npos)
     {
-      std::string::size_type eol = text.find ("\n", found + 1);
+      auto eol = text.find ("\n", found + 1);
       if (eol != std::string::npos)
       {
         std::string value = text.substr (
@@ -135,7 +166,7 @@ std::string CmdEdit::formatDate (
   std::string value = task.get (attribute);
   if (value.length ())
   {
-    Date dt (value);
+    ISO8601d dt (value);
     value = dt.toString (dateformat);
   }
 
@@ -150,8 +181,8 @@ std::string CmdEdit::formatDuration (
   std::string value = task.get (attribute);
   if (value.length ())
   {
-    Duration dur (value);
-    value = dur.formatSeconds ();
+    ISO8601p dur (value);
+    value = dur.format ();
   }
 
   return value;
@@ -161,8 +192,7 @@ std::string CmdEdit::formatDuration (
 std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
 {
   std::stringstream before;
-  bool verbose = context.verbose ("edit") ||
-                 context.config.getBoolean ("edit.verbose"); // Deprecated 2.0
+  bool verbose = context.verbose ("edit");
 
   if (verbose)
     before << "# " << STRING_EDIT_HEADER_1 << "\n"
@@ -185,11 +215,10 @@ std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
          << "# " << STRING_EDIT_TABLE_HEADER_2 << "\n"
          << "# ID:                " << task.id                                          << "\n"
          << "# UUID:              " << task.get ("uuid")                                << "\n"
-         << "# Status:            " << ucFirst (Task::statusToText (task.getStatus ())) << "\n"
+         << "# Status:            " << ucFirst (Task::statusToText (task.getStatus ())) << "\n"  // L10N safe ucFirst.
          << "# Mask:              " << task.get ("mask")                                << "\n"
          << "# iMask:             " << task.get ("imask")                               << "\n"
-         << "  Project:           " << task.get ("project")                             << "\n"
-         << "  Priority:          " << task.get ("priority")                            << "\n";
+         << "  Project:           " << task.get ("project")                             << "\n";
 
   std::vector <std::string> tags;
   task.getTags (tags);
@@ -209,6 +238,7 @@ std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
          << "  Until:             " << formatDate (task, "until", dateformat)           << "\n"
          << "  Recur:             " << task.get ("recur")                               << "\n"
          << "  Wait until:        " << formatDate (task, "wait", dateformat)            << "\n"
+         << "# Modified:          " << formatDate (task, "modified", dateformat)        << "\n"
          << "  Parent:            " << task.get ("parent")                              << "\n";
 
   if (verbose)
@@ -218,15 +248,14 @@ std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
 
   std::map <std::string, std::string> annotations;
   task.getAnnotations (annotations);
-  std::map <std::string, std::string>::iterator anno;
-  for (anno = annotations.begin (); anno != annotations.end (); ++anno)
+  for (auto& anno : annotations)
   {
-    Date dt (strtol (anno->first.substr (11).c_str (), NULL, 10));
+    ISO8601d dt (strtol (anno.first.substr (11).c_str (), NULL, 10));
     before << "  Annotation:        " << dt.toString (dateformat)
-           << " -- "                  << anno->second << "\n";
+           << " -- "                  << json::encode (anno.second) << "\n";
   }
 
-  Date now;
+  ISO8601d now;
   before << "  Annotation:        " << now.toString (dateformat) << " -- \n";
 
   // Add dependencies here.
@@ -254,30 +283,28 @@ std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
 
   // UDAs
   std::vector <std::string> udas;
-  std::map <std::string, Column*>::iterator col;
-  for (col = context.columns.begin (); col != context.columns.end (); ++col)
-    if (context.config.get ("uda." + col->first + ".type") != "")
-      udas.push_back (col->first);
+  for (auto& col : context.columns)
+    if (context.config.get ("uda." + col.first + ".type") != "")
+      udas.push_back (col.first);
 
   if (udas.size ())
   {
     before << "# " << STRING_EDIT_UDA_SEP << "\n";
     std::sort (udas.begin (), udas.end ());
-    std::vector <std::string>::iterator uda;
-    for (uda = udas.begin (); uda != udas.end (); ++uda)
+    for (auto& uda : udas)
     {
-      int pad = 13 - uda->length ();
+      int pad = 13 - uda.length ();
       std::string padding = "";
       if (pad > 0)
         padding = std::string (pad, ' ');
 
-      std::string type = context.config.get ("uda." + *uda + ".type");
+      std::string type = context.config.get ("uda." + uda + ".type");
       if (type == "string" || type == "numeric")    
-        before << "  UDA " << *uda << ": " << padding << task.get (*uda) << "\n";
+        before << "  UDA " << uda << ": " << padding << task.get (uda) << "\n";
       else if (type == "date")
-        before << "  UDA " << *uda << ": " << padding << formatDate (task, *uda, dateformat) << "\n";
+        before << "  UDA " << uda << ": " << padding << formatDate (task, uda, dateformat) << "\n";
       else if (type == "duration")
-        before << "  UDA " << *uda << ": " << padding << formatDuration (task, *uda) << "\n";
+        before << "  UDA " << uda << ": " << padding << formatDuration (task, uda) << "\n";
     }
   }
 
@@ -289,15 +316,14 @@ std::string CmdEdit::formatTask (Task task, const std::string& dateformat)
   {
     before << "# " << STRING_EDIT_UDA_ORPHAN_SEP << "\n";
     std::sort (orphans.begin (), orphans.end ());
-    std::vector <std::string>::iterator orphan;
-    for (orphan = orphans.begin (); orphan != orphans.end (); ++orphan)
+    for (auto& orphan : orphans)
     {
-      int pad = 6 - orphan->length ();
+      int pad = 6 - orphan.length ();
       std::string padding = "";
       if (pad > 0)
         padding = std::string (pad, ' ');
 
-      before << "  UDA Orphan " << *orphan << ": " << padding << task.get (*orphan) << "\n";
+      before << "  UDA Orphan " << orphan << ": " << padding << task.get (orphan) << "\n";
     }
   }
 
@@ -324,25 +350,6 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
     }
   }
 
-  // priority
-  value = findValue (after, "\n  Priority:");
-  if (task.get ("priority") != value)
-  {
-    if (value != "")
-    {
-      if (context.columns["priority"]->validate (value))
-      {
-        context.footnote (STRING_EDIT_PRIORITY_MOD);
-        task.set ("priority", value);
-      }
-    }
-    else
-    {
-      context.footnote (STRING_EDIT_PRIORITY_DEL);
-      task.remove ("priority");
-    }
-  }
-
   // tags
   value = findValue (after, "\n  Tags:");
   std::vector <std::string> tags;
@@ -351,7 +358,7 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
   task.addTags (tags);
 
   // description.
-  value = findValue (after, "\n  Description:");
+  value = findMultilineValue (after, "\n  Description:", "\n  Created:");
   if (task.get ("description") != value)
   {
     if (value != "")
@@ -372,7 +379,7 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
     if (formatted != value)
     {
       context.footnote (STRING_EDIT_ENTRY_MOD);
-      task.set ("entry", Date(value, dateformat).toEpochString ());
+      task.set ("entry", ISO8601d (value, dateformat).toEpochString ());
     }
   }
   else
@@ -389,13 +396,13 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
       if (formatted != value)
       {
         context.footnote (STRING_EDIT_START_MOD);
-        task.set ("start", Date(value, dateformat).toEpochString ());
+        task.set ("start", ISO8601d (value, dateformat).toEpochString ());
       }
     }
     else
     {
       context.footnote (STRING_EDIT_START_MOD);
-      task.set ("start", Date(value, dateformat).toEpochString ());
+      task.set ("start", ISO8601d (value, dateformat).toEpochString ());
     }
   }
   else
@@ -418,7 +425,7 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
       if (formatted != value)
       {
         context.footnote (STRING_EDIT_END_MOD);
-        task.set ("end", Date(value, dateformat).toEpochString ());
+        task.set ("end", ISO8601d (value, dateformat).toEpochString ());
       }
     }
     else if (task.getStatus () != Task::deleted)
@@ -445,13 +452,13 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
       if (formatted != value)
       {
         context.footnote (STRING_EDIT_SCHED_MOD);
-        task.set ("scheduled", Date(value, dateformat).toEpochString ());
+        task.set ("scheduled", ISO8601d (value, dateformat).toEpochString ());
       }
     }
     else
     {
       context.footnote (STRING_EDIT_SCHED_MOD);
-      task.set ("scheduled", Date(value, dateformat).toEpochString ());
+      task.set ("scheduled", ISO8601d (value, dateformat).toEpochString ());
     }
   }
   else
@@ -475,13 +482,13 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
       if (formatted != value)
       {
         context.footnote (STRING_EDIT_DUE_MOD);
-        task.set ("due", Date(value, dateformat).toEpochString ());
+        task.set ("due", ISO8601d (value, dateformat).toEpochString ());
       }
     }
     else
     {
       context.footnote (STRING_EDIT_DUE_MOD);
-      task.set ("due", Date(value, dateformat).toEpochString ());
+      task.set ("due", ISO8601d (value, dateformat).toEpochString ());
     }
   }
   else
@@ -512,13 +519,13 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
       if (formatted != value)
       {
         context.footnote (STRING_EDIT_UNTIL_MOD);
-        task.set ("until", Date(value, dateformat).toEpochString ());
+        task.set ("until", ISO8601d (value, dateformat).toEpochString ());
       }
     }
     else
     {
       context.footnote (STRING_EDIT_UNTIL_MOD);
-      task.set ("until", Date(value, dateformat).toEpochString ());
+      task.set ("until", ISO8601d (value, dateformat).toEpochString ());
     }
   }
   else
@@ -536,8 +543,9 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
   {
     if (value != "")
     {
-      Duration d;
-      if (d.valid (value))
+      ISO8601p p;
+      std::string::size_type idx = 0;
+      if (p.parse (value, idx))
       {
         context.footnote (STRING_EDIT_RECUR_MOD);
         if (task.get ("due") != "")
@@ -573,14 +581,14 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
       if (formatted != value)
       {
         context.footnote (STRING_EDIT_WAIT_MOD);
-        task.set ("wait", Date(value, dateformat).toEpochString ());
+        task.set ("wait", ISO8601d (value, dateformat).toEpochString ());
         task.setStatus (Task::waiting);
       }
     }
     else
     {
       context.footnote (STRING_EDIT_WAIT_MOD);
-      task.set ("wait", Date(value, dateformat).toEpochString ());
+      task.set ("wait", ISO8601d (value, dateformat).toEpochString ());
       task.setStatus (Task::waiting);
     }
   }
@@ -617,14 +625,14 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
   {
     found += 14;  // Length of "\n  Annotation:".
 
-    std::string::size_type eol = after.find ("\n", found + 1);
+    auto eol = after.find ("\n", found + 1);
     if (eol != std::string::npos)
     {
       std::string value = trim (after.substr (
         found,
         eol - found), "\t ");
 
-      std::string::size_type gap = value.find (" -- ");
+      auto gap = value.find (" -- ");
       if (gap != std::string::npos)
       {
         // TODO keeping the initial dates even if dateformat approximates them
@@ -634,17 +642,24 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
         // for each line: if the annotation is the same, then it is copied; if
         // the annotation is modified, then its original date may be kept; and
         // if there is no corresponding id, then a new unique date is created).
-        Date when (value.substr (0, gap), dateformat);
+        ISO8601d when (value.substr (0, gap), dateformat);
 
-        // This guarantees that if more than one annotation has the same date,
-        // that the seconds will be different, thus unique, thus not squashed.
-        // Bug #249
-        when += (const int) annotations.size ();
+        // If the map already contains a annotation for a given timestamp
+        // we need to increment until we find an unused key
+        int timestamp = (int) when.toEpoch ();
 
         std::stringstream name;
-        name << "annotation_" << when.toEpoch ();
+
+        do
+        {
+          name.str ("");  // Clear
+          name << "annotation_" << timestamp;
+          timestamp++;
+        }
+        while (annotations.find (name.str ()) != annotations.end ());
+
         std::string text = trim (value.substr (gap + 4), "\t ");
-        annotations.insert (std::make_pair (name.str (), text));
+        annotations.insert (std::make_pair (name.str (), json::decode (text)));
       }
     }
   }
@@ -657,35 +672,33 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
   split (dependencies, value, ",");
 
   task.remove ("depends");
-  std::vector <std::string>::iterator dep;
-  for (dep = dependencies.begin (); dep != dependencies.end (); ++dep)
+  for (auto& dep : dependencies)
   {
-    if (dep->length () >= 7)
-      task.addDependency (*dep);
+    if (dep.length () >= 7)
+      task.addDependency (dep);
     else
-      task.addDependency ((int) strtol (dep->c_str (), NULL, 10));
+      task.addDependency ((int) strtol (dep.c_str (), NULL, 10));
   }
 
   // UDAs
-  std::map <std::string, Column*>::iterator col;
-  for (col = context.columns.begin (); col != context.columns.end (); ++col)
+  for (auto& col : context.columns)
   {
-    std::string type = context.config.get ("uda." + col->first + ".type");
+    std::string type = context.config.get ("uda." + col.first + ".type");
     if (type != "")
     {
-      std::string value = findValue (after, "\n  UDA " + col->first + ":");
-      if ((task.get (col->first) != value) && (type != "date" ||
-           (task.get (col->first) != Date (value, dateformat).toEpochString ())) &&
+      std::string value = findValue (after, "\n  UDA " + col.first + ":");
+      if ((task.get (col.first) != value) && (type != "date" ||
+           (task.get (col.first) != ISO8601d (value, dateformat).toEpochString ())) &&
            (type != "duration" ||
-           (task.get (col->first) != (std::string) Duration (value) )))
+           (task.get (col.first) != (std::string) ISO8601p (value))))
       {
         if (value != "")
         {
-          context.footnote (format (STRING_EDIT_UDA_MOD, col->first));
+          context.footnote (format (STRING_EDIT_UDA_MOD, col.first));
 
           if (type == "string")
           {
-            task.set (col->first, value);
+            task.set (col.first, value);
           }
           else if (type == "numeric")
           {
@@ -693,40 +706,37 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
             double d;
             if (n.getNumber (d) &&
                 n.depleted ())
-              task.set (col->first, value);
+              task.set (col.first, value);
             else
               throw format (STRING_UDA_NUMERIC, value);
           }
           else if (type == "date")
           {
-            Date d (value, dateformat);
-            task.set (col->first, d.toEpochString ());
+            task.set (col.first, ISO8601d (value, dateformat).toEpochString ());
           }
           else if (type == "duration")
           {
-            Duration d (value);
-            task.set (col->first, (time_t) d);
+            task.set (col.first, (time_t) ISO8601p (value));
           }
         }
         else
         {
-          context.footnote (format (STRING_EDIT_UDA_DEL, col->first));
-          task.remove (col->first);
+          context.footnote (format (STRING_EDIT_UDA_DEL, col.first));
+          task.remove (col.first);
         }
       }
     }
   }
-  
+
   // UDA orphans
   std::vector <std::string> orphanValues = findValues (after, "\n  UDA Orphan ");
-  std::vector <std::string>::iterator orphan;
-  for (orphan = orphanValues.begin (); orphan != orphanValues.end (); ++orphan)
+  for (auto& orphan : orphanValues)
   {
-    std::string::size_type colon = orphan->find (':');
+    auto colon = orphan.find (':');
     if (colon != std::string::npos)
     {
-      std::string name  = trim (orphan->substr (0, colon),  "\t ");
-      std::string value = trim (orphan->substr (colon + 1), "\t ");
+      std::string name  = trim (orphan.substr (0, colon),  "\t ");
+      std::string value = trim (orphan.substr (colon + 1), "\t ");
 
       if (value != "")
         task.set (name, value);
@@ -737,7 +747,7 @@ void CmdEdit::parseTask (Task& task, const std::string& after, const std::string
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-bool CmdEdit::editFile (Task& task)
+CmdEdit::editResult CmdEdit::editFile (Task& task)
 {
   // Check for file permissions.
   Directory location (context.config.get ("data.location"));
@@ -746,7 +756,7 @@ bool CmdEdit::editFile (Task& task)
 
   // Create a temp file name in data.location.
   std::stringstream file;
-  file << "task." << getpid () << "." << task.id << ".task";
+  file << "task." << task.get ("uuid").substr (0, 8) << ".task";
 
   // Determine the output date format, which uses a hierarchy of definitions.
   //   rc.dateformat.edit
@@ -760,6 +770,11 @@ bool CmdEdit::editFile (Task& task)
   int ignored = chdir (location._data.c_str ());
   ++ignored; // Keep compiler quiet.
 
+  // Check if the file already exists, if so, bail out
+  Path filepath = Path (file.str ());
+  if (filepath.exists ())
+    throw std::string (STRING_EDIT_IN_PROGRESS);
+
   // Format the contents, T -> text, write to a file.
   std::string before = formatTask (task, dateformat);
   std::string before_orig = before;
@@ -782,10 +797,16 @@ ARE_THESE_REALLY_HARMFUL:
 
   // Launch the editor.
   std::cout << format (STRING_EDIT_LAUNCHING, editor) << "\n";
-  if (-1 == system (editor.c_str ()))
-    std::cout << STRING_EDIT_NO_EDITS << "\n";
-  else
+  int exitcode = system (editor.c_str ());
+  if (0 == exitcode)
     std::cout << STRING_EDIT_COMPLETE << "\n";
+  else
+  {
+    std::cout << format (STRING_EDIT_FAILED, exitcode) << "\n";
+    if (-1 == exitcode)
+      std::cout << std::strerror (errno) << "\n";
+    return CmdEdit::editResult::error;
+  }
 
   // Slurp file.
   std::string after;
@@ -833,7 +854,9 @@ ARE_THESE_REALLY_HARMFUL:
   // Cleanup.
   File::remove (file.str ());
   ignored = chdir (current_dir.c_str ());
-  return changes;
+  return changes
+         ? CmdEdit::editResult::changes
+         : CmdEdit::editResult::nochanges;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
