@@ -39,15 +39,21 @@ extern Context context;
 ////////////////////////////////////////////////////////////////////////////////
 CmdStart::CmdStart ()
 {
-  _keyword     = "start";
-  _usage       = "task <filter> start <mods>";
-  _description = STRING_CMD_START_USAGE;
-  _read_only   = false;
-  _displays_id = false;
+  _keyword               = "start";
+  _usage                 = "task <filter> start <mods>";
+  _description           = STRING_CMD_START_USAGE;
+  _read_only             = false;
+  _displays_id           = false;
+  _needs_gc              = false;
+  _uses_context          = true;
+  _accepts_filter        = true;
+  _accepts_modifications = true;
+  _accepts_miscellaneous = false;
+  _category              = Command::Category::operation;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-int CmdStart::execute (std::string& output)
+int CmdStart::execute (std::string&)
 {
   int rc = 0;
   int count = 0;
@@ -66,34 +72,40 @@ int CmdStart::execute (std::string& output)
   std::map <std::string, std::string> projectChanges;
 
   bool nagged = false;
-  std::vector <Task>::iterator task;
-  for (task = filtered.begin (); task != filtered.end (); ++task)
+  for (auto& task : filtered)
   {
-    if (! task->has ("start"))
+    if (! task.has ("start"))
     {
-      Task before (*task);
+      Task before (task);
 
       // Start the specified task.
       std::string question = format (STRING_CMD_START_CONFIRM,
-                                     task->id,
-                                     task->get ("description"));
-      task->modify (Task::modAnnotate);
-      task->setAsNow ("start");
+                                     task.id,
+                                     task.get ("description"));
+      task.modify (Task::modAnnotate);
+      task.setAsNow ("start");
+
+      Task::status status = task.getStatus ();
+      if (status == Task::completed || status == Task::deleted)
+      {
+        // "waiting" handled by Task::validate(), no special care needed here.
+        task.setStatus (Task::pending);
+      }
 
       if (context.config.getBoolean ("journal.time"))
-        task->addAnnotation (context.config.get ("journal.time.start.annotation"));
+        task.addAnnotation (context.config.get ("journal.time.start.annotation"));
 
-      if (permission (*task, taskDifferences (before, *task) + question, filtered.size ()))
+      if (permission (taskDifferences (before, task) + question, filtered.size ()))
       {
-        updateRecurrenceMask (*task);
-        context.tdb2.modify (*task);
+        updateRecurrenceMask (task);
+        context.tdb2.modify (task);
         ++count;
-        feedback_affected (STRING_CMD_START_TASK, *task);
+        feedback_affected (STRING_CMD_START_TASK, task);
         if (!nagged)
-          nagged = nag (*task);
-        dependencyChainOnStart (*task);
+          nagged = nag (task);
+        dependencyChainOnStart (task);
         if (context.verbose ("project"))
-          projectChanges[task->get ("project")] = onProjectChange (*task, false);
+          projectChanges[task.get ("project")] = onProjectChange (task, false);
       }
       else
       {
@@ -106,18 +118,17 @@ int CmdStart::execute (std::string& output)
     else
     {
       std::cout << format (STRING_CMD_START_ALREADY,
-                           task->id,
-                           task->get ("description"))
+                           task.id,
+                           task.get ("description"))
                 << "\n";
       rc = 1;
     }
   }
 
   // Now list the project changes.
-  std::map <std::string, std::string>::iterator i;
-  for (i = projectChanges.begin (); i != projectChanges.end (); ++i)
-    if (i->first != "")
-      context.footnote (i->second);
+  for (auto& change : projectChanges)
+    if (change.first != "")
+      context.footnote (change.second);
 
   feedback_affected (count == 1 ? STRING_CMD_START_1 : STRING_CMD_START_N, count);
   return rc;
