@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-import os
-import tempfile
-import shutil
 import atexit
+import json
+import os
+import shlex
+import shutil
+import tempfile
 import unittest
-from .utils import (run_cmd_wait, run_cmd_wait_nofail, which,
-                    task_binary_location)
 from .exceptions import CommandError
 from .hooks import Hooks
+from .utils import run_cmd_wait, run_cmd_wait_nofail, which, task_binary_location
+from .compat import STRING_TYPE
 
 
 class Task(object):
@@ -47,10 +49,8 @@ class Task(object):
 
         self.reset_env()
 
-        # Cannot call self.config until confirmation is disabled
         with open(self.taskrc, 'w') as rc:
             rc.write("data.location={0}\n"
-                     "confirmation=no\n"
                      "hooks=off\n"
                      "".format(self.datadir))
 
@@ -135,7 +135,7 @@ class Task(object):
         """
         # Add -- to avoid misinterpretation of - in things like UUIDs
         cmd = (self.taskw, "config", "--", var, value)
-        return run_cmd_wait(cmd, env=self.env)
+        return run_cmd_wait(cmd, env=self.env, input="y\n")
 
     @property
     def taskrc_content(self):
@@ -146,7 +146,54 @@ class Task(object):
         with open(self.taskrc, "r") as f:
             return f.readlines()
 
-    def runSuccess(self, args=(), input=None, merge_streams=False,
+    def export(self, export_filter=None):
+        """Run "task export", return JSON array of exported tasks."""
+        if export_filter is None:
+            export_filter = ""
+
+        code, out, err = self.runSuccess("rc.json.array=1 {0} export"
+                                         "".format(export_filter))
+
+        return json.loads(out)
+
+    def export_one(self, export_filter=None):
+        """
+        Return a dictionary representing the exported task. Will
+        fail if mutliple tasks match the filter.
+        """
+
+        result = self.export(export_filter=export_filter)
+
+        if len(result) != 1:
+            descriptions = [task.get('description') or '[description-missing]'
+                            for task in result]
+
+            raise ValueError(
+                "One task should match the '{0}' filter, '{1}' "
+                "matches:\n    {2}".format(
+                    export_filter or '',
+                    len(result),
+                    '\n    '.join(descriptions)
+                ))
+
+        return result[0]
+
+    @property
+    def latest(self):
+        return self.export_one("+LATEST")
+
+    @staticmethod
+    def _split_string_args_if_string(args):
+        """Helper function to parse and split into arguments a single string
+        argument. The string is literally the same as if written in the shell.
+        """
+        # Enable nicer-looking calls by allowing plain strings
+        if isinstance(args, STRING_TYPE):
+            args = shlex.split(args)
+
+        return args
+
+    def runSuccess(self, args="", input=None, merge_streams=False,
                    timeout=5):
         """Invoke task with given arguments and fail if exit code != 0
 
@@ -155,7 +202,7 @@ class Task(object):
 
         If you wish to pass instructions to task such as confirmations or other
         input via stdin, you can do so by providing a input string.
-        Such as input="y\ny".
+        Such as input="y\ny\n".
 
         If merge_streams=True stdout and stderr will be merged into stdout.
 
@@ -168,18 +215,7 @@ class Task(object):
         # Create a copy of the command
         command = self._command[:]
 
-        # Enable nicer-looking calls by allowing plain strings
-        try:
-            # Python 2.x
-            if isinstance(args, basestring):
-                import shlex
-                args = shlex.split(args)
-        except NameError:
-            # Python 3.x
-            if isinstance(args, str):
-                import shlex
-                args = shlex.split(args)
-
+        args = self._split_string_args_if_string(args)
         command.extend(args)
 
         output = run_cmd_wait_nofail(command, input,
@@ -200,7 +236,7 @@ class Task(object):
 
         If you wish to pass instructions to task such as confirmations or other
         input via stdin, you can do so by providing a input string.
-        Such as input="y\ny".
+        Such as input="y\ny\n".
 
         If merge_streams=True stdout and stderr will be merged into stdout.
 
@@ -212,6 +248,8 @@ class Task(object):
         """
         # Create a copy of the command
         command = self._command[:]
+
+        args = self._split_string_args_if_string(args)
         command.extend(args)
 
         output = run_cmd_wait_nofail(command, input,
@@ -260,7 +298,7 @@ class Task(object):
         which should be the output of any previous process that failed.
         """
         try:
-            output = self.runSuccess(("diag",))
+            output = self.runSuccess("diag")
         except CommandError as e:
             # If task diag failed add the error to stderr
             output = (e.code, None, str(e))
