@@ -29,7 +29,7 @@
 #include <test.h>
 
 ////////////////////////////////////////////////////////////////////////////////
-int main (int argc, char** argv)
+int main (int, char**)
 {
   UnitTest t (33);
 
